@@ -11,20 +11,16 @@ pub struct RelayBoard {
 }
 
 impl RelayBoard {
-    pub fn new(addr: u8) -> Option<Self> {
-        match I2c::from_path("/dev/i2c-1") {
-            Ok(b) => {
-                Some(
-                    RelayBoard {
-                        num_relays: 4,
-                        dev_addr: addr,
-                        dev_reg_mode1: 0x60,
-                        dev_reg_data: 0xff,
-                        bus: b,
-                    }
-                )
-            },
-            Err(_) => None,
+    pub fn new(addr: u8) -> Self {
+        let mut b = I2c::from_path("/dev/i2c-1").unwrap();
+        b.smbus_set_slave_address(addr.into(), false).unwrap();
+
+        RelayBoard {
+            num_relays: 4,
+            dev_addr: addr,
+            dev_reg_mode1: 0x60,
+            dev_reg_data: 0xff,
+            bus: b,
         }
     }
 
